@@ -4,10 +4,11 @@ Find download path for a torrent, hardlinking existing files
 
 import collections
 import difflib
+import errno
 import functools
 import os
 
-from ..utils import LazyModule, fs, torrent
+from ..utils import LazyModule, fs
 from . import JobBase
 
 import logging  # isort:skip
@@ -69,10 +70,6 @@ class DownloadLocationJob(JobBase):
 
     def _get_target_location(self):
         file_candidates = self._get_file_candidates()
-        if file_candidates:
-            _log.debug('### Finding piece-matching files')
-        else:
-            _log.debug('### Failed to find any size-matching files')
 
         links = {}
         target_location = None
@@ -100,7 +97,8 @@ class DownloadLocationJob(JobBase):
 
     def _verify_file(self, file):
         _log.debug('Verifying content of %r at %r', file, self._check_location)
-        with torrent.TorrentFileStream(self._torrent, self._check_location) as tfs:
+        content_path = os.path.join(self._check_location, self._torrent.name)
+        with torf.TorrentFileStream(self._torrent, content_path=content_path) as tfs:
             # Don't check the first and the last piece of a file as they likely
             # overlap with another file that might be either invalid or missing
             file_piece_indexes = tfs.get_absolute_piece_indexes(file, (1, -2))
@@ -200,7 +198,19 @@ class DownloadLocationJob(JobBase):
         return torrentfile.size == fs.file_size(filepath)
 
     def _create_hardlink(self, source, target):
-        return self._create_link(os.link, source, target)
+        return self._create_link(self._hardlink_or_symlink, source, target)
+
+    def _hardlink_or_symlink(self, source, target):
+        # Try hard link and default to symlink
+        try:
+            os.link(source, target)
+        except OSError as e:
+            if e.errno == errno.EXDEV:
+                # Invalid cross-device link (`source` and `target` are on
+                # different file systems)
+                os.symlink(source, target)
+            else:
+                raise
 
     def _create_symlink(self, source, target):
         return self._create_link(os.symlink, source, target)
@@ -210,7 +220,6 @@ class DownloadLocationJob(JobBase):
             # Create parent directory if it doesn't exist
             target_parent = os.path.dirname(target)
             try:
-                # _log.debug(f'os.makedirs({target_parent!r}, exist_ok=True)')
                 os.makedirs(target_parent, exist_ok=True)
             except OSError as e:
                 msg = e.strerror if e.strerror else e
