@@ -740,8 +740,8 @@ class ReleaseName(collections.abc.Mapping):
                 if title_normalized == normalize_title(result.title)
             ]
 
-            def has_duplicates(seq):
-                tupl = tuple(seq)
+            def has_duplicates(it):
+                tupl = tuple(it)
                 for item in tupl:
                     if tupl.count(item) > 1:
                         return True
@@ -753,13 +753,13 @@ class ReleaseName(collections.abc.Mapping):
                     parts.append(result['countries'][0])
                 if year and result['year']:
                     parts.append(result['year'])
-                return ','.join(parts)
+                return parts
 
             if has_duplicates(make_title(r) for r in results):
-                if not has_duplicates(make_title(r, country=True) for r in results):
-                    self.country_required = True
-                elif not has_duplicates(make_title(r, year=True) for r in results):
+                if not has_duplicates(make_title(r, year=True) for r in results):
                     self.year_required = True
+                elif not has_duplicates(make_title(r, country=True) for r in results):
+                    self.country_required = True
 
     def format(self, sep=' '):
         """Assemble all parts into string"""
