@@ -4,12 +4,12 @@ Scene release search and verification
 
 from ... import utils
 from .. import release
-from . import predb, srrdb
+from . import predbde, predbovh, srrdb
 from .base import SceneDbApiBase
 from .find import SceneQuery, search
-from .verify import (assert_not_abbreviated_filename, is_scene_release,
-                     release_files, verify_release, verify_release_files,
-                     verify_release_name)
+from .verify import (assert_not_abbreviated_filename, is_abbreviated_filename,
+                     is_mixed_scene_release, is_scene_release, release_files,
+                     verify_release, verify_release_files, verify_release_name)
 
 
 def scenedbs():
