@@ -13,14 +13,14 @@ def webdbs():
     return subclasses(WebDbApiBase, submodules(__package__))
 
 
-def webdb(name, **kwargs):
+def webdb(name, config=None):
     """
     Create :class:`.WebDbApiBase` instance
 
     :param str name: Name of the DB. A subclass of :class:`.WebDbApiBase` with
         the same :attr:`~.WebDbApiBase.name` must exist in one of this package's
         submodules.
-    :param kwargs: All keyword arguments are passed to the subclass specified by
+    :param dict config: User configuration passed to the subclass specified by
         `name`
 
     :raise ValueError: if no matching subclass can be found
@@ -29,7 +29,7 @@ def webdb(name, **kwargs):
     """
     for cls in webdbs():
         if cls.name == name:
-            return cls(**kwargs)
+            return cls(config=config)
     raise ValueError(f'Unsupported web database: {name}')
 
 
